import { MPDProtocol } from '../protocol';
export declare class ConnectionCommands {
    private protocol;
    constructor(protocol: MPDProtocol);
    /**
     * Closes the connection to MPD. MPD will try to send the remaining output buffer before it
     * actually closes the connection, but that cannot be guaranteed. This command will not
     * generate a response.
     */
    close(): void;
    /**
     * Kills MPD.
     */
    kill(): void;
    /**
     * This is used for authentication with the server. `password` is simply the plaintext password.
     */
    password(password: string): Promise<void>;
    /**
     * Does nothing but return "OK".
     */
    ping(): Promise<void>;
    /**
     * Shows a list of available tag types. It is an intersection of the
     * metadata_to_use setting and this client's tag mask.
     * About the tag mask: each client can decide to disable any number of tag types,
     * which will be omitted from responses to this client.
     * That is a good idea, because it makes responses smaller.
     */
    tagTypes(): Promise<string[]>;
    /**
     * Remove one or more tags from the list of tag types the client is interested in.
     * These will be omitted from responses to this client.
     */
    disableTagTypes(names: string[]): Promise<void>;
    /**
     * Re-enable one or more tags from the list of tag types for this client.
     * These will no longer be hidden from responses to this client.
     */
    enableTagTypes(names: string[]): Promise<void>;
    /**
     * Clear the list of tag types this client is interested in.
     * This means that MPD will not send any tags to this client.
     */
    clearTagTypes(): Promise<void>;
    /**
     * Announce that this client is interested in all tag types.
     * This is the default setting for new clients.
     */
    allTagTypes(): Promise<void>;
}
export declare function tagTypes(protocol: MPDProtocol): Promise<string[]>;
