"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.tagTypes = exports.ConnectionCommands = void 0;
var ConnectionCommands = /** @class */ (function () {
    function ConnectionCommands(protocol) {
        this.protocol = protocol;
    }
    /**
     * Closes the connection to MPD. MPD will try to send the remaining output buffer before it
     * actually closes the connection, but that cannot be guaranteed. This command will not
     * generate a response.
     */
    ConnectionCommands.prototype.close = function () {
        this.protocol.sendCommand('close');
    };
    /**
     * Kills MPD.
     */
    ConnectionCommands.prototype.kill = function () {
        this.protocol.sendCommand('kill');
    };
    /**
     * This is used for authentication with the server. `password` is simply the plaintext password.
     */
    ConnectionCommands.prototype.password = function (password) {
        return __awaiter(this, void 0, void 0, function () {
            var cmd;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        cmd = "password \"" + password + "\"";
                        return [4 /*yield*/, this.protocol.sendCommand(cmd)];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        });
    };
    /**
     * Does nothing but return "OK".
     */
    ConnectionCommands.prototype.ping = function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.protocol.sendCommand('ping')];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        });
    };
    /**
     * Shows a list of available tag types. It is an intersection of the
     * metadata_to_use setting and this client's tag mask.
     * About the tag mask: each client can decide to disable any number of tag types,
     * which will be omitted from responses to this client.
     * That is a good idea, because it makes responses smaller.
     */
    ConnectionCommands.prototype.tagTypes = function () {
        return tagTypes(this.protocol);
    };
    /**
     * Remove one or more tags from the list of tag types the client is interested in.
     * These will be omitted from responses to this client.
     */
    ConnectionCommands.prototype.disableTagTypes = function (names) {
        return __awaiter(this, void 0, void 0, function () {
            var cmd;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        if (names.length < 1)
                            return [2 /*return*/];
                        cmd = "tagtypes disable " + names.join(' ');
                        return [4 /*yield*/, this.protocol.sendCommand(cmd)];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        });
    };
    /**
     * Re-enable one or more tags from the list of tag types for this client.
     * These will no longer be hidden from responses to this client.
     */
    ConnectionCommands.prototype.enableTagTypes = function (names) {
        return __awaiter(this, void 0, void 0, function () {
            var cmd;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        if (names.length < 1)
                            return [2 /*return*/];
                        cmd = "tagtypes enable " + names.join(' ');
                        return [4 /*yield*/, this.protocol.sendCommand(cmd)];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        });
    };
    /**
     * Clear the list of tag types this client is interested in.
     * This means that MPD will not send any tags to this client.
     */
    ConnectionCommands.prototype.clearTagTypes = function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.protocol.sendCommand('tagtypes clear')];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        });
    };
    /**
     * Announce that this client is interested in all tag types.
     * This is the default setting for new clients.
     */
    ConnectionCommands.prototype.allTagTypes = function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.protocol.sendCommand('tagtypes all')];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        });
    };
    return ConnectionCommands;
}());
exports.ConnectionCommands = ConnectionCommands;
function tagTypes(protocol) {
    return __awaiter(this, void 0, void 0, function () {
        var lines;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, protocol.sendCommand('tagtypes')];
                case 1:
                    lines = _a.sent();
                    return [2 /*return*/, lines.map(function (line) { return line.substring(9); })];
            }
        });
    });
}
exports.tagTypes = tagTypes;
//# sourceMappingURL=connection.js.map